function tracepedestal,image,h=h,imax=imax
;+
; NAME: 
;     TRACEPEDESTAL.PRO
;
; PURPOSE:
;    Determine the readout pedestal in TRACE images by averaging
;    the signal level in the corners of the images.  Note this 
;    only works with full-frame images.  Doesn't differentiate 
;    pedestal level from dark current.
; 
; CALLING SEQUENCE:
;     pedestal=tracepedestal(image, h=h, imax=imax)
;
; INPUTS:
;     input - image
;
; OUTPUTS:
;     tracepedestal - value of pedestal
;     h             - histogram of intensities below 1000 DN
;     imax          - most likely intensity
;
; [Abbreviated] HISTORY:
;     30-Sep-98 - (BNH) - Added a real doc header
;                       - Added some diagnostics so this
;                         falls over if the image is not 1024x1024
;                       - Removed some trailing garbage from the file, 
;                         this thing never worked as is
;+

sz = (size(image))(1:2)
if ((sz[0] ne 1024) or (sz[1] ne 1024)) then begin
    message, /info, 'Input image is not 1024x1024.  Aborting.'
    return, 0
endif

h=histogram(image,min=0,bin=1,max=1000)
dummy=max(h,imax)
; use the four corner of the image to determine the pedestal
pedestal=total(image(1:30,1:30) + $
               image(1023-30:1023,1:30) + $
               image(1:30,1023-30:1023) + $
               image(1023-30:1023,1023-30:1023))/(4.*30.^2)

return,pedestal
end
